/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2008  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS version: 3.60d                                         *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS SH7203 Starterkit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define _NUM_LEDS        (4)

/****** SFRs and identifiers used for LED demo **********************/

#define _PEDRL    (*(volatile unsigned short*) (0xFFFE3A02))
#define _PECRL3   (*(volatile unsigned short*) (0xFFFE3A12))
#define _PECRL4   (*(volatile unsigned short*) (0xFFFE3A10))
#define _PEIORL   (*(volatile unsigned short*) (0xFFFE3A06))

#define _PCDRL    (*(volatile unsigned short*) (0xFFFE3902))
#define _PCCRL4   (*(volatile unsigned short*) (0xFFFE3910))
#define _PCIORL   (*(volatile unsigned short*) (0xFFFE3906))

/****** Assign LEDs to Ports ****************************************/

#define _LED0_PORT        (_PEDRL)
#define _LED1_PORT        (_PEDRL)
#define _LED2_PORT        (_PCDRL)
#define _LED3_PORT        (_PEDRL)

#define _LED0_BIT         (10)
#define _LED1_BIT         (12)
#define _LED2_BIT         (14)
#define _LED3_BIT         (11)

#define _LED0_PCRL_REG    (_PECRL3)
#define _LED1_PCRL_REG    (_PECRL4)
#define _LED2_PCRL_REG    (_PCCRL4)
#define _LED3_PCRL_REG    (_PECRL3)

#define _LED0_PIORL_REG   (_PEIORL)
#define _LED1_PIORL_REG   (_PEIORL)
#define _LED2_PIORL_REG   (_PCIORL)
#define _LED3_PIORL_REG   (_PEIORL)

#define _LED0_PCRL_MD_POS (_PECRL3)
#define _LED1_PCRL_MD_POS (_PECRL4)
#define _LED2_PCRL_MD_POS (_PCCRL4)
#define _LED3_PCRL_MD_POS (_PECRL3)


#define _LED0_MASK        (1 << _LED0_BIT)
#define _LED1_MASK        (1 << _LED1_BIT)
#define _LED2_MASK        (1 << _LED2_BIT)
#define _LED3_MASK        (1 << _LED3_BIT)

/*********************************************************************
*
*       Local functions
*
**********************************************************************
*/

static unsigned char _LEDIsOn(int Index) {
  unsigned char result;
  result = 0;
  switch (Index) {
    case 0:
      result = (_LED0_PORT & _LED0_MASK) ? 0 : 1;    // LED0 is switched on with low level
      break;
    case 1: 
      result = (_LED1_PORT & _LED1_MASK) ? 0 : 1;    // LED1 is switched on with low level
      break;
    case 2: 
      result = (_LED2_PORT & _LED2_MASK) ? 0 : 1;    // LED2 is switched on with low level
      break;
    case 3: 
      result = (_LED3_PORT & _LED3_MASK) ? 0 : 1;    // LED3 is switched on with low level
      break;
    default:
    break;
  }
  return result;
}

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Configure port pins connected to LEDs, set Port mode
  //
  _LED0_PCRL_REG &= ~(0xf << _LED0_PCRL_MD_POS);
  _LED1_PCRL_REG &= ~(0xf << _LED1_PCRL_MD_POS);
  _LED2_PCRL_REG &= ~(0xf << _LED2_PCRL_MD_POS);
  _LED3_PCRL_REG &= ~(0xf << _LED3_PCRL_MD_POS);
  //
  // Set mode of port to output mode
  //
  _LED0_PIORL_REG |= (1 << _LED0_BIT);
  _LED1_PIORL_REG |= (1 << _LED1_BIT);
  _LED2_PIORL_REG |= (1 << _LED2_BIT);
  _LED3_PIORL_REG |= (1 << _LED3_BIT);
  //
  // Initially switch LEDs on for test
  //
  _LED0_PORT &= ~(_LED0_MASK);    // LED0 is switched on with low level
  _LED1_PORT &= ~(_LED1_MASK);    // LED1 is switched on with low level
  _LED2_PORT &= ~(_LED2_MASK);    // LED2 is switched on with low level
  _LED3_PORT &= ~(_LED3_MASK);    // LED3 is switched on with low level
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch (Index) {
    case 0:
      _LED0_PORT &= ~(_LED0_MASK);    // LED0 is switched on with low level
      break;
    case 1: 
      _LED1_PORT &= ~(_LED1_MASK);    // LED1 is switched on with low level
      break;
    case 2: 
      _LED2_PORT &= ~(_LED2_MASK);    // LED2 is switched on with low level
      break;
    case 3: 
      _LED3_PORT &= ~(_LED3_MASK);    // LED3 is switched on with low level
      break;
    default:
      break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch (Index) {
    case 0:
      _LED0_PORT |= (_LED0_MASK);    // LED0 is switched off with high level
      break;
    case 1: 
      _LED1_PORT |= (_LED1_MASK);    // LED1 is switched off with high level
      break;
    case 2: 
      _LED2_PORT |= (_LED2_MASK);    // LED2 is switched off with high level
      break;
    case 3: 
      _LED3_PORT |= (_LED3_MASK);    // LED3 is switched off with high level
      break;
    default:
      break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch (Index) {
    case 0:
      if(_LEDIsOn(Index)) {
        _LED0_PORT |= (_LED0_MASK);    // LED0 is switched off with high level
      } else {
        _LED0_PORT &= ~(_LED0_MASK);    // LED0 is switched on with low level
    }
      break;
    case 1: 
      if(_LEDIsOn(Index)) {
        _LED1_PORT |= (_LED1_MASK);    // LED1 is switched off with high level
      } else {
        _LED1_PORT &= ~(_LED1_MASK);    // LED1 is switched on with low level
    }
      break;
    case 2: 
      if(_LEDIsOn(Index)) {
        _LED2_PORT |= (_LED2_MASK);    // LED2 is switched off with high level
      } else {
        _LED2_PORT &= ~(_LED2_MASK);    // LED2 is switched on with low level
    }
      break;
    case 3: 
      if(_LEDIsOn(Index)) {
        _LED3_PORT |= (_LED3_MASK);    // LED3 is switched off with high level
      } else {
        _LED3_PORT &= ~(_LED3_MASK);    // LED3 is switched on with low level
    }
      break;
    default:
      break;
  }
}

/****** EOF *********************************************************/


