/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2008  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS version: 3.60d                                         *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : RTOSInit_SH7203.c            (for RENESAS SH2A SH7203)
Purpose : Initializes and handles the hardware for embOS as far
          as required by embOS.
          Feel free to modify this file acc. to your
          target system.
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "RTOS.H"

/*********************************************************************
*
*                    Configuration
*
**********************************************************************
*/

#ifndef   ALLOW_NESTED_INTERRUPTS
  #define ALLOW_NESTED_INTERRUPTS (1)
#endif

#ifndef OS_FSYS
  /* Internal MTU clock frequency                                   */
  /* Depends on external oscillator and PLL settings used           */
  /* We assume Clock mode 0 with 16.66 MHz oscillator at EXTAL      */
  /* The PLL is initialized in the function                         */
  /* ConfigureOperatingFrequency() in hwsetup.c                     */
  #define OS_FSYS (200000000L)  /* Standard setting is 200 MHz      */
#endif

#ifndef   OS_PCLK_DIVIDER
  #define OS_PCLK_DIVIDER  (6)
#endif
  
#ifndef   OS_PCLK_TIMER
  #define OS_PCLK_TIMER (OS_FSYS / OS_PCLK_DIVIDER / 8)
#endif
  
#ifndef   OS_PCLK_UART
  #define OS_PCLK_UART (OS_FSYS / OS_PCLK_DIVIDER)
#endif

/* Select UART for embOSView.
   If you do not want (or can not due to hardware limitations) to dedicate
   a UART to embOSView, please define it to be -1
   Currently the standard code below supports CPU internal UART0 and 1
   (But can be easily changed to other UARTs)
*/
#ifndef   OS_UART
  #define OS_UART (0)
#endif    
#ifndef   OS_BAUDRATE
  #define OS_BAUDRATE (38400L)
#endif

#ifndef   SUPPORT_BANK_SWITCH
  #define SUPPORT_BANK_SWITCH (0)    /* Does not work with KPIT GNU */
#endif

/******	End of configurable option **********************************/

#define OS_UART_USED (OS_UART == 0) // Other UARTS are not tested and
                                    // will require minor modification 

/*********************************************************************
*
*		Local defines
*
**********************************************************************
*/

/*********************************************************************
*
*		SFRs used in RTOSInit
*/
#define _STB_BASE_ADDR  (0xFFFE0000)
#define _STBCR4  (*(volatile OS_U8* ) (_STB_BASE_ADDR + 0x040C))

#define _CMT_BASE_ADDR (0xFFFEC000)
#define _CMSTR         (*(volatile OS_U16*) (_CMT_BASE_ADDR + 0x00))
#define _CMCSR_0       (*(volatile OS_U16*) (_CMT_BASE_ADDR + 0x02))
#define _CMCNT_0       (*(volatile OS_U16*) (_CMT_BASE_ADDR + 0x04))
#define _CMCOR_0       (*(volatile OS_U16*) (_CMT_BASE_ADDR + 0x06))

#define _CMT_CMSR0_CMF_BIT (7)
#define _CMT_MODULE_ID_BIT (2)

#define _INTC_BASE_ADDR (0xfffe0800)
#define _INTC_IBCR      (*(volatile OS_U16*) (_INTC_BASE_ADDR + 0x000c)) 
#define _INTC_IBNR      (*(volatile OS_U16*) (_INTC_BASE_ADDR + 0x000e)) 
#define _INTC_IPR08     (*(volatile OS_U16*) (_INTC_BASE_ADDR + 0x0404)) 
#define _INTC_IPR13     (*(volatile OS_U16*) (_INTC_BASE_ADDR + 0x040E)) 
#define _INTC_IPR14     (*(volatile OS_U16*) (_INTC_BASE_ADDR + 0x0410)) 

#define _INTC_CMT0_PRIO_REG    _INTC_IPR08
#define _CMT0_PRIO_POS         (4)
#define _CMT0_PRIO_MASK        (~(0x0F << _CMT0_PRIO_POS))

#if OS_UART_USED
  #define _SCIF0_BASE_ADDR  (0xFFFE8000)
  #define _SCIF1_BASE_ADDR  (0xFFFE8800)
  #define _SCIF2_BASE_ADDR  (0xFFFE9000)
  #define _SCIF3_BASE_ADDR  (0xFFFE9800)
  
  #define _PECRL1     (*(volatile OS_U16*) (0xFFFE3A16)) 
  #define _PECRL2     (*(volatile OS_U16*) (0xFFFE3A14)) 
  #define _PECRL4     (*(volatile OS_U16*) (0xFFFE3A10)) 
  #define _PEIORL     (*(volatile OS_U16*) (0xFFFE3A06))

  #define BAUDPRESCALE 0  // CKE bits: 0,1,2,3
  #define BAUDDIVIDE ((OS_PCLK_UART+(OS_BAUDRATE*16L))/(OS_BAUDRATE*32L))-1
  #if (OS_UART == 0)
    #define _SCIFx_MODULE_ID_BIT  (7)
	#define _SCIF_BASE_ADDR       (_SCIF0_BASE_ADDR)
    #define _INTC_SCIFx_PRIO_REG  (_INTC_IPR13)
	#define _SCIFx_PRIO_POS       (8)
    #define _PECRLx               (_PECRL1)
    #define _PE_MD_TXD_POS  (4)
    #define _PE_MD_RXD_POS  (0)
    #define _PE_TXD_PIN     (1)
    #define _PE_RXD_PIN     (0)
  #elif (OS_UART == 1)
    #define _SCIFx_MODULE_ID_BIT  (6)
	#define _SCIF_BASE_ADDR       (_SCIF1_BASE_ADDR)
    #define _INTC_SCIFx_PRIO_REG  (_INTC_IPR13)
	#define _SCIFx_PRIO_POS       (4)
    #define _PECRLx               (_PECRL2)
    #define _PE_MD_TXD_POS  (4)
    #define _PE_MD_RXD_POS  (0)
    #define _PE_TXD_PIN     (5)
    #define _PE_RXD_PIN     (4)
  #elif (OS_UART == 2)
    #define _SCIFx_MODULE_ID_BIT  (5)
	#define _SCIF_BASE_ADDR       (_SCIF2_BASE_ADDR)
    #define _INTC_SCIFx_PRIO_REG  (_INTC_IPR13)
	#define _SCIFx_PRIO_POS       (0)
    #define _PECRLx               (_PECRL2)
    #define _PE_MD_TXD_POS  (12)
    #define _PE_MD_RXD_POS  (8)
    #define _PE_TXD_PIN     (7)
    #define _PE_RXD_PIN     (6)
  #elif (OS_UART == 3)
    #define _SCIFx_MODULE_ID_BIT  (4)
	#define _SCIF_BASE_ADDR       (_SCIF3_BASE_ADDR)
    #define _INTC_SCIFx_PRIO_REG  (_INTC_IPR14)
	#define _SCIFx_PRIO_POS       (12)
    #define _PECRLx               (_PECRL4)
    #define _PE_MD_TXD_POS  (4)
    #define _PE_MD_RXD_POS  (0)
    #define _PE_TXD_PIN     (13)
    #define _PE_RXD_PIN     (12)
  #endif

#define _SCIFx_SCSMR  (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x00)) 
#define _SCIFx_SCBRR  (*(volatile OS_U8* ) (_SCIF_BASE_ADDR + 0x04)) 
#define _SCIFx_SCSCR  (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x08)) 
#define _SCIFx_SCFTDR (*(volatile OS_U8* ) (_SCIF_BASE_ADDR + 0x0C)) 
#define _SCIFx_SCFSR  (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x10)) 
#define _SCIFx_SCFRDR (*(volatile OS_U8* ) (_SCIF_BASE_ADDR + 0x14)) 
#define _SCIFx_SCFCR  (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x18)) 
#define _SCIFx_SCFDR  (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x1C)) 
#define _SCIFx_SCSPTR (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x20)) 
#define _SCIFx_SCLSR  (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x24)) 
#define _SCIFx_SCEMR  (*(volatile OS_U16*) (_SCIF_BASE_ADDR + 0x28)) 

#define _SCSCR_REIE_BIT (3)
#define _SCSCR_RE_BIT   (4)
#define _SCSCR_TE_BIT   (5)
#define _SCSCR_RIE_BIT  (6)
#define _SCSCR_TIE_BIT  (7)

#define _SCFSR_DR_BIT   (0)
#define _SCFSR_RDF_BIT  (1)
#define _SCFSR_PER_BIT  (2)
#define _SCFSR_FER_BIT  (3)
#define _SCFSR_BRK_BIT  (4)
#define _SCFSR_TDFE_BIT (5)
#define _SCFSR_TEND_BIT (6)
#define _SCFSR_ER_BIT   (7)

#define _PE_MDRXD_MASK  (0xF << _PE_MD_RXD_POS)
#define _PE_MDTXD_MASK  (0xF << _PE_MD_TXD_POS)

#endif /* OS_UART_USED */

/*********************************************************************
*
*		Local functions
*
**********************************************************************
*/

#if (OS_UART_USED)
/*********************************************************************
*
*		_IsrUartRxHandler()
*/
static void _IsrUartRxHandler(void) {
  if (_SCIFx_SCFSR & (1 << _SCFSR_RDF_BIT)) {
    OS_U8 Data;
    Data = _SCIFx_SCFRDR;      // Get data
    _SCIFx_SCFSR &= ~(1 << _SCFSR_RDF_BIT);  
    OS_OnRx(Data);             // Process data
  }
}

/*********************************************************************
*
*		_IsrUartTxHandler()
*/
static void _IsrUartTxHandler(void) {
  if (OS_OnTx()) {
    _SCIFx_SCSCR &= ~(1 << _SCSCR_TIE_BIT);      // Disable Tx-Int
  }
}

/*********************************************************************
*
*		_IsrUartErrHandler()
*/
static void _IsrUartErrHandler(void) {
  _SCIFx_SCSCR  &= ~(0x50);   // disable Rx and Rx-Int
  while (_SCIFx_SCFSR & ((1 << 7) | (1 << 4) | (1 << 3) | (1 << 2))) {  // Any error (ER, BRK, FER, PER)?
    _SCIFx_SCFSR    &= ~((1 << 7) | (1 << 4) | (1 << 3) | (1 << 2));    // Clear error and Rx data flags 
  }   
  while (_SCIFx_SCLSR & (1 << 0)) {  // Overrun error ?
    _SCIFx_SCLSR &= ~(1 << 0);       // Clear error
  }   
  _SCIFx_SCSCR |= 0x50;     // Reenable Rx and Rx-Int
}
#endif  /* OS_UART_USED */

/*********************************************************************
*
*		_IsrTickHandler()
*/
static void _IsrTickHandler(void) {
  /* Clear the interrupt flag	*/
  _CMCSR_0 &= ~(1 << _CMT_CMSR0_CMF_BIT);
  OS_HandleTick();
}

/*********************************************************************
*
*		Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*		    OS_InitHW()
*
*  Initialize the hardware required for the OS to run. This will work
*  on any target hardware, but may have to be tailored a little
*  (regarding the clock frequency). Of course the same holds true
*  if for some reason you choose to use an other timer.
*  Per default we use the Compare match timer channel 0, which is an up-counter
*/
#define TIMER_RELOAD (OS_PCLK_TIMER / 1000)
void OS_InitHW(void) {
  OS_IncDI();                       // For Safety disable interrupts

  //
  // Enable module clock for CMT and initialize CMT
  //
  _STBCR4 &= ~(1 << _CMT_MODULE_ID_BIT);              
  _CMSTR  &= ~(1 << 0);              // Stop counter channel 0
  _CMCOR_0 = TIMER_RELOAD;           // Initialize compare value
  _CMCNT_0 = 0;                      // Reset counter
  _CMCSR_0 = 0                       // Set divider to 1/8
          | (1 << 6)                 // Compare match interrupt enable
		  ;
  _INTC_CMT0_PRIO_REG &= _CMT0_PRIO_MASK;
  _INTC_CMT0_PRIO_REG |= (1 << _CMT0_PRIO_POS);         // Set interrupt priority, enable lowest

  _CMSTR  |= (1 << 0);               // Start timer

#if SUPPORT_BANK_SWITCH
  _INTC_IBNR = 0
             | (1 << 14)  // Enable Bank switching for all interrupts
             | (0 << 13)  // 1: => Enable Bank Overflow interrupt
             ;
#endif
  
  OS_COM_Init();                    // Initialize UART for embOSView
  OS_SetFastIntPriorityLimit(8);    // Set Priority limit for "Fast" interrupts 
  OS_DecRI();
}

/*********************************************************************
*
*       Idle loop  (OS_Idle)
*
*  Please note:
*  This is basically the "core" of the idle loop.
*  This core loop can be changed, but:
*  The idle loop does not have a stack of its own, therefore no
*  functionality should be implemented that relies on the stack
*  to be preserved. However, a simple program loop can be programmed
*  (like toggeling an output or incrementing a counter)
*/
void OS_Idle(void) {          // Idle loop: No task is ready to exec
  for (;;);                   // Nothing to do ... wait for a interrupt
}

/*********************************************************************
*
*       Get time [cycles]
*
*  This routine is required for task-info via embOSView or high
*  resolution time measurement.
*  It returns the system time in clock cycles.
*/
OS_U32 OS_GetTime_Cycles(void) {
  OS_U32 Time;
  OS_U32 Cnt;
  
  Time = OS_GetTime32();
  Cnt  = _CMCNT_0;
  //  
  // Check if timer interrupt pending ...
  // 
  if ((_CMCSR_0 & (1 << 7)) != 0) {  // Adjust result
    Cnt = _CMCNT_0;
    Time++;
  } 
  return (TIMER_RELOAD * Time) + Cnt;
}

/*********************************************************************
*
*       OS_ConvertCycles2us
*
*  Convert Cycles into micro seconds. When using 20.0 MHz, this
*  means dividing by 20. If you have a different clock frequency,
*  you may have to modify this routine in order to get proper
*  diagonstics. Please note: Operation of theOS is not affected
*  by this routine. It is used for profiling and testing
*/
OS_U32 OS_ConvertCycles2us(OS_U32 Cycles) {
  return Cycles/(OS_PCLK_TIMER/1000000);
}

/*********************************************************************
*
*       OS_ISR_Tick(), the embOS timer interrupt handler
*/
#pragma interrupt (OS_ISR_Tick(resbank))
void OS_ISR_Tick(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrTickHandler);
  #else
    OS_CallISR(_IsrTickHandler);
  #endif
}

/*********************************************************************
*
*       Communication for embOSView   (UART 0)
*
**********************************************************************
*/

#if OS_UART_USED
/*********************************************************************
*
*       OS_COM_Init()
*/
void OS_COM_Init(void) {
  int i;
  OS_U16 PortMode;
  
  OS_IncDI();                           // Disable interrupts, save previous state
  //
  // Configure the port pins connected to UART
  //
  PortMode  = _PECRLx;
  PortMode &= ~(_PE_MDRXD_MASK | _PE_MDTXD_MASK); // Clear control setting
  PortMode |=  (0x03 << _PE_MD_RXD_POS) | (0x03 << _PE_MD_TXD_POS);  // Set SCIF-function (0x03)
  _PECRLx   = PortMode;
  _PEIORL  &= ~(1 << _PE_RXD_PIN);  // Set data direction for RxD to input
  _PEIORL  |=  (1 << _PE_TXD_PIN);  // Set data direction for TxD to input
  //
  // Enable selected UART peripheral
  //
  _STBCR4 &= ~(1 << _SCIFx_MODULE_ID_BIT);              
  //
  // Disable transmission, reception & serial interrupts
  //
  _SCIFx_SCSCR = 0x0000;
  //
  // Initialize the FIFO control register, disable FIFO
  //
  _SCIFx_SCFCR = 0x0000;
  //
  // Initializes the serial mode register
  //
  _SCIFx_SCSMR = 0x0000    // B15:B8 - Reserved - Set to 0
               | (0 << 7)  // B7 - Communication mode; 0: Asynchronous
               | (0 << 6)  // B6 - Character length;   0: 8 bit data
               | (0 << 5)  // B5 - Parity Enable;      0: No Parity
               | (0 << 4)  // B4 - Parity mode;        0: N/A (set to 0)
               | (0 << 3)  // B3 - Stop bit length;    0: 1 stop bit
               | (0 << 2)  // B2 - Reserved - Set to 0
               | (0 << 0)  // B1:B0 - Clock Select     0: Select Pphi as source clock
               ;
  //
  // Initialize Baudrate generator
  //
  _SCIFx_SCBRR = BAUDDIVIDE;

  for(i=0 ; i < 10500 ; i++) {
    /* Settling delay (1 bit cycle) */
  }
  //
  // Initialize serial status register
  //
  _SCIFx_SCFSR = 0x0000;
  //
  // Set interrupt priority for SCI, enables interrupt
  //
  _INTC_SCIFx_PRIO_REG = (0x01 << _SCIFx_PRIO_POS);
  //
  // Enable transmission, reception and receive interrupts
  //
  _SCIFx_SCSCR |= 0x0070;
  OS_DecRI();                           // Restore interrupt state
}

/*********************************************************************
*
*       OS_COM_Send1()
*/
void OS_COM_Send1(OS_U8 c) {
  _SCIFx_SCFTDR = c;
  _SCIFx_SCFSR  &=~(1 << _SCFSR_TDFE_BIT);     // Clear Tx Empty Flag
  _SCIFx_SCSCR  |= (1 << _SCSCR_TIE_BIT);      // Enable Tx-Int
}

/*********************************************************************
*
*       OS_ISR_rx()
*/
#pragma interrupt (OS_ISR_Rx(resbank))
void OS_ISR_Rx(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartRxHandler);
  #else
    OS_CallISR(_IsrUartRxHandler);
  #endif
}

/*********************************************************************
*
*       OS_ISR_tx()
*/
#pragma interrupt(OS_ISR_Tx(resbank))
void OS_ISR_Tx (void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartTxHandler);
  #else
    OS_CallISR(_IsrUartTxHandler);
  #endif
}

/*********************************************************************
*
*       OS_ISR_RxErr()
*/
#pragma interrupt (OS_ISR_RxErr(resbank))
void OS_ISR_RxErr(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartErrHandler);
  #else
    OS_CallISR(_IsrUartErrHandler);
  #endif
}

#else  /* No communication routines */
  void OS_COM_Init(void) {}
  void OS_COM_Send1(OS_U8 c) {
    OS_COM_ClearTxActive();  /* let OS know that transmitter is not busy  */
  }
#endif /* (OS_UART_USED)

/****** End of file *************************************************/
