/***********************************************************************************
FILE NAME  	: vecttbl.c

DESCRIPTION	: Vector Table

Note - 
'#pragma section' used in this file instructs the linker to place all subsequent code
in the named section. This can be used to relocate code in the memory map. This
directive should be used when debugging code in RAM to provide a section name that
can be referenced in the build | toolchain | linker | section settings. Use of the
directive without the section name will reset the section to default. 

Copyright   : 2007 Renesas Technology Europe Ltd.
Copyright   : 2007 Renesas Technology Corporation.
All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
23.02.2007 RTE-VNA First Release
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/
/*	Following header file provides vector locations for the interrupts. */
#include "vect.h"
#include "OS_Config.h"

typedef void (*fp) (void);
extern void start(void);
extern void stack (void);

extern void Initialise (void);
extern void Dummy (void);

#ifndef   OS_UART
  #define OS_UART (0)
#endif
  
#if (OS_UART == -1)
  #define OS_UART_USED (0)
#else
  #define OS_UART_USED (1)
#endif  
  
/***********************************************************************************
Vector Table
***********************************************************************************/
//#pragma section VECTTBL

//void *RESET_Vectors[] = 
#define VECT_SECT          __attribute__ ((section (".vects")))

const fp HardwareVectors[] VECT_SECT  = {
/*	0 Power On Reset PC	*/
//Initialise,
    start,

/*	1 Power On Reset SP	*/
    (fp)stack,

/*	2 Manual Reset PC	*/
//Initialise,
    start,

/*	3 Manual Reset SP	*/
    (fp)stack,
//};

//#pragma section

//#pragma section INTTBL

//void *INT_Vectors[] = 
//{
/*	4 Illegal code	*/
(void*) INT_Illegal_code,

/*	5 Reserved	*/
(void*) Dummy,

/*	6 Illegal slot	*/
(void*) INT_Illegal_slot,

/*	7 Reserved	*/
(void*) Dummy,

/*	8 Reserved	*/
(void*) Dummy,

/*	9 CPU Address error	*/
(void*) INT_CPU_Address,

/* 10 DMAC Address error */
(void*) INT_DMAC_Address,

/*	11 NMI	*/
(void*) INT_NMI,

/*	12 User breakpoint trap	*/
(void*) INT_User_Break,

/*	13 FPU exception */
(void*) EXP_FPU_EXCEPTION,

/* 14 H-UDI */
(void*) INT_HUDI,

/* 15 Register bank over */
(void*) INT_Bank_Overflow,

/* 16 Register bank under */
(void*) INT_Bank_Underflow,

/* 17 ZERO DIV */
(void*) INT_Divide_by_Zero,

/* 18 OVER DIV */
(void*) INT_Divide_Overflow,

/*	19 Reserved	*/
(void*) Dummy,

/*	20 Reserved	*/
(void*) Dummy,

/*	21 Reserved	*/
(void*) Dummy,

/*	22 Reserved	*/
(void*) Dummy,

/*	23 Reserved	*/
(void*) Dummy,

/*	24 Reserved	*/
(void*) Dummy,

/*	25 Reserved	*/
(void*) Dummy,

/*	26 Reserved	*/
(void*) Dummy,

/*	27 Reserved	*/
(void*) Dummy,

/*	28 Reserved	*/
(void*) Dummy,

/*	29 Reserved	*/
(void*) Dummy,

/*	30 Reserved	*/
(void*) Dummy,

/*	31 Reserved	*/
(void*) Dummy,

/*	32 TRAPA (User Vecter)	*/
(void*) INT_TRAPA32,

/*	33 TRAPA (User Vecter)	*/
(void*) INT_TRAPA33,

/*	34 TRAPA (User Vecter)	*/
(void*) INT_TRAPA34,

/*	35 TRAPA (User Vecter)	*/
(void*) INT_TRAPA35,

/*	36 TRAPA (User Vecter)	*/
(void*) INT_TRAPA36,

/*	37 TRAPA (User Vecter)	*/
(void*) INT_TRAPA37,

/*	38 TRAPA (User Vecter)	*/
(void*) INT_TRAPA38,

/*	39 TRAPA (User Vecter)	*/
(void*) INT_TRAPA39,

/*	40 TRAPA (User Vecter)	*/
(void*) INT_TRAPA40,

/*	41 TRAPA (User Vecter)	*/
(void*) INT_TRAPA41,

/*	42 TRAPA (User Vecter)	*/
(void*) INT_TRAPA42,

/*	43 TRAPA (User Vecter)	*/
(void*) INT_TRAPA43,

/*	44 TRAPA (User Vecter)	*/
(void*) INT_TRAPA44,

/*	45 TRAPA (User Vecter)	*/
(void*) INT_TRAPA45,

/*	46 TRAPA (User Vecter)	*/
(void*) INT_TRAPA46,

/*	47 TRAPA (User Vecter)	*/
(void*) INT_TRAPA47,

/*	48 TRAPA (User Vecter)	*/
(void*) INT_TRAPA48,

/*	49 TRAPA (User Vecter)	*/
(void*) INT_TRAPA49,

/*	50 TRAPA (User Vecter)	*/
(void*) INT_TRAPA50,

/*	51 TRAPA (User Vecter)	*/
(void*) INT_TRAPA51,

/*	52 TRAPA (User Vecter)	*/
(void*) INT_TRAPA52,

/*	53 TRAPA (User Vecter)	*/
(void*) INT_TRAPA53,

/*	54 TRAPA (User Vecter)	*/
(void*) INT_TRAPA54,

/*	55 TRAPA (User Vecter)	*/
(void*) INT_TRAPA55,

/*	56 TRAPA (User Vecter)	*/
(void*) INT_TRAPA56,

/*	57 TRAPA (User Vecter)	*/
(void*) INT_TRAPA57,

/*	58 TRAPA (User Vecter)	*/
(void*) INT_TRAPA58,

/*	59 TRAPA (User Vecter)	*/
(void*) INT_TRAPA59,

/*	60 TRAPA (User Vecter)	*/
(void*) INT_TRAPA60,

/*	61 TRAPA (User Vecter)	*/
(void*) INT_TRAPA61,

/*	62 TRAPA (User Vecter)	*/
(void*) INT_TRAPA62,

/*	63 TRAPA (User Vecter)	*/
(void*) INT_TRAPA63,

/* 64 Interrupt IRQ0 */
(void*) INT_IRQ0,

/* 65 Interrupt IRQ1 */
(void*) INT_IRQ1,

/*	66 Interrupt IRQ2	*/
(void*) INT_IRQ2,

/*	67 Interrupt IRQ3	*/
(void*) INT_IRQ3,

/* 68 Interrupt IRQ4 */
(void*) INT_IRQ4,

/* 69 Interrupt IRQ5 */
(void*) INT_IRQ5,

/* 70 Interrupt IRQ6 */
(void*) INT_IRQ6,

/* 71 Interrupt IRQ7 */
(void*) INT_IRQ7,

/* 72 Reserved */
(void*) Dummy,

/* 73 Reserved */
(void*) Dummy,

/* 74 Reserved */
(void*) Dummy,

/* 75 Reserved */
(void*) Dummy,

/* 76 Reserved	*/
(void*) Dummy,

/* 77 Reserved	*/
(void*) Dummy,

/* 78 Reserved	*/
(void*) Dummy,

/* 79 Reserved	*/
(void*) Dummy,

/* 80  PINT0   */
(void*) INT_PINT0,

/* 81  PINT1 */
(void*) INT_PINT1,

/* 82  PINT2 */
(void*) INT_PINT2,

/* 83  PINT3 */
(void*) INT_PINT3,

/* 84  PINT4 */
(void*) INT_PINT4,

/* 85  PINT5 */
(void*) INT_PINT5,

/* 86  PINT6 */
(void*) INT_PINT6,

/* 87  PINT7 */
(void*) INT_PINT7,

/* 88 Reserved */
(void*) Dummy,

/* 89 Reserved */
(void*) Dummy,

/* 90 Reserved */
(void*) Dummy,

/* 91 Reserved */
(void*) Dummy,

/* 92 Reserved */
(void*) Dummy,

/* 93 Reserved */
(void*) Dummy,

/* 94 Reserved */
(void*) Dummy,

/* 95 Reserved */
(void*) Dummy,

/* 96 Reserved */
(void*) Dummy,

/* 97 Reserved */
(void*) Dummy,

/* 98 Reserved	*/
(void*) Dummy,

/* 99 Reserved	*/
(void*) Dummy,

/* 100 Reserved */
(void*) Dummy,

/* 101 Reserved */
(void*) Dummy,

/* 102 Reserved */
(void*) Dummy,

/* 103 Reserved */
(void*) Dummy,

/* 104 Reserved */
(void*) Dummy,

/* 105 Reserved */
(void*) Dummy,

/* 106 Reserved */
(void*) Dummy,

/* 107 Reserved */
(void*) Dummy,

/* 108 DMAC0 TEI0 */
(void*) INT_DMAC0_DEI0,

/* 109 DMAC0 HEI0 */
(void*) INT_DMAC0_HEI0,

/*	110 Reserved */
(void*) Dummy,

/*	111 Reserved */
(void*) Dummy,

/* 112 DMAC1 TEI1 */
(void*) INT_DMAC1_DEI1,

/* 113 DMAC1 HEI1 */
(void*) INT_DMAC1_HEI1,

/* 114 Reserved */
(void*) Dummy,

/* 115 Reserved */
(void*) Dummy,

/* 116 DMAC2 TEI2 */
(void*) INT_DMAC2_DEI2,

/* 117 DMAC2 HEI2 */
(void*) INT_DMAC2_HEI2,

/*	118 Reserved */
(void*) Dummy,

/*	119 Reserved */
(void*) Dummy,

/* 120 DMAC3 TEI3 */
(void*) INT_DMAC3_DEI3,

/* 121 DMAC3 HEI3 */
(void*) INT_DMAC3_HEI3,

/* 122 Reserved */
(void*) Dummy,
/* 123 Reserved */
(void*) Dummy,

/* 124 DMAC4 TEI4 */
(void*) INT_DMAC4_DEI4,

/* 125 DMAC4 HEI4 */
(void*) INT_DMAC4_HEI4,

/*	126 Reserved */
(void*) Dummy,

/*	127 Reserved */
(void*) Dummy,

/* 128 DMAC5 TEI5 */
(void*) INT_DMAC5_DEI5,

/* 129 DMAC5 HEI5 */
(void*) INT_DMAC5_HEI5,

/* 130 Reserved */
(void*) Dummy,

/*	131 Reserved */
(void*) Dummy,

/* 132 DMAC6 TEI6 */
(void*) INT_DMAC6_DEI6,

/* 133 DMAC6 HEI6 */
(void*) INT_DMAC6_HEI6,

/*	134 Reserved */
(void*) Dummy,

/*	135 Reserved */
(void*) Dummy,

/* 136 DMAC7 TEI7 */
(void*) INT_DMAC7_DEI7,

/* 137 DMAC7 HEI7 */
(void*) INT_DMAC7_HEI7,

/*	138 Reserved */
(void*) Dummy,

/*	139 Reserved */
(void*) Dummy,

/* 140 USBI */
(void*) INT_USB_USBI,

/* 141 LCDCI */
(void*) INT_LCDC_LCDCI,

/* 142 CMT CMI0 */
//(void*) INT_CMT_CMI0,
(void*) OS_ISR_Tick,

#ifndef OS_TEST
/* 143 CMT CMI1 */
(void*) INT_CMT_CMI1,
#else
/* 143 CMT CMI1 */
(void*) OSTest_X_ISR,
#endif

/* 144 BSC CMI */
(void*) INT_BSC_CMI,

/* 145 WDT ITI */
(void*) INT_WDT_ITI,

/* 146 MTU2 MTU0 TGI0A */
(void*) INT_MTU2_MTU0_TGI0A,

/* 147 MTU2 MTU0 TGI0B */
(void*) INT_MTU2_MTU0_TGI0B,

/* 148 MTU2 MTU0 TGI0C */
(void*) INT_MTU2_MTU0_TGI0C,

/* 149 MTU2 MTU0 TGI0D */
(void*) INT_MTU2_MTU0_TGI0D,

/* 150 MTU2 MTU0 TGI0V */
(void*) INT_MTU2_MTU0_TGI0V,

/* 151 MTU2 MTU0 TGI0E */
(void*) INT_MTU2_MTU0_TGI0E,

/* 152 MTU2 MTU0 TGI0F */
(void*) INT_MTU2_MTU0_TGI0F,

/* 153 MTU2 MTU1 TGI1A */
(void*) INT_MTU2_MTU1_TGI1A,

/* 154 MTU2 MTU1 TGI1B */
(void*) INT_MTU2_MTU1_TGI1B,

/* 155 MTU2 MTU1 TGI1V */
(void*) INT_MTU2_MTU1_TGI1V,

/* 156 MTU2 MTU1 TGI1U */
(void*) INT_MTU2_MTU1_TGI1U,

/* 157 MTU2 MTU2 TGI2A */
(void*) INT_MTU2_MTU2_TGI2A,

/* 158 MTU2 MTU2 TGI2B */
(void*) INT_MTU2_MTU2_TGI2B,

/* 159 MTU2 MTU2 TGI2V */
(void*) INT_MTU2_MTU2_TGI2V,

/* 160 MTU2 MTU2 TGI2U */
(void*) INT_MTU2_MTU2_TGI2U,

/* 161 MTU2 MTU3 TGI3A */
(void*) INT_MTU2_MTU3_TGI3A,

/* 162 MTU2 MTU3 TGI3B */
(void*) INT_MTU2_MTU3_TGI3B,

/* 163 MTU2 MTU3 TGI3C */
(void*) INT_MTU2_MTU3_TGI3C,

/* 164 MTU2 MTU3 TGI3D */
(void*) INT_MTU2_MTU3_TGI3D,

/* 165 MTU2 MTU3 TGI3V */
(void*) INT_MTU2_MTU3_TGI3V,

/* 166 MTU2 MTU4 TGI4A */
(void*) INT_MTU2_MTU4_TGI4A,

/* 167 MTU2 MTU4 TGI4B */
(void*) INT_MTU2_MTU4_TGI4B,

/* 168 MTU2 MTU4 TGI4C */
(void*) INT_MTU2_MTU4_TGI4C,

/* 169 MTU2 MTU4 TGI4D */
(void*) INT_MTU2_MTU4_TGI4D,

/* 170 MTU2 MTU4 TGI4V */
(void*) INT_MTU2_MTU4_TGI4V,

/* 171 ADC ADI */
(void*) INT_ADC_ADI,

/* 172 IIC3-0 STPI0 */
(void*) INT_IIC30_STPI0,

/* 173 IIC3-0 NAKI0  */
(void*) INT_IIC30_NAKI0,

/* 174 IIC3-0 RXI0  */
(void*) INT_IIC30_RXI0,

/* 175 IIC3-0 TXI0 */
(void*) INT_IIC30_TXI0,

/* 176 IIC3-0 TEI0 */
(void*) INT_IIC30_TEI0,

/* 177 IIC3-1 STPI1 */
(void*) INT_IIC31_STPI1,

/* 178 IIC3-1 NAKI1  */
(void*) INT_IIC31_NAKI1,

/* 179 IIC3-1 RXI1  */
(void*) INT_IIC31_RXI1,

/* 180 IIC3-1 TXI1 */
(void*) INT_IIC31_TXI1,

/* 181 IIC3-1 TEI1 */
(void*) INT_IIC31_TEI1,

/* 182 IIC3-2 STPI2 */
(void*) INT_IIC32_STPI2,

/* 183 IIC3-2 NAKI2  */
(void*) INT_IIC32_NAKI2,

/* 184 IIC3-2 RXI2  */
(void*) INT_IIC32_RXI2,

/* 185 IIC3-2 TXI2 */
(void*) INT_IIC32_TXI2,

/* 186 IIC3-2 TEI2 */
(void*) INT_IIC32_TEI2,

/* 187 IIC3-3 STPI3 */
(void*) INT_IIC33_STPI3,

/* 188 IIC3-3 NAKI3  */
(void*) INT_IIC33_NAKI3,

/* 189 IIC3-3 RXI3  */
(void*) INT_IIC33_RXI3,

/* 190 IIC3-3 TXI3 */
(void*) INT_IIC33_TXI3,

/* 191 IIC3-3 TEI3 */
(void*) INT_IIC33_TEI3,

#if (OS_UART_USED && (OS_UART == 0))
  /* 192 SCIF SCIF0 BRI0 */
  (void*) OS_ISR_RxErr,

  /* 193 SCIF SCIF0 ERI0 */
  (void*) OS_ISR_RxErr,

  /* 194 SCIF SCIF0 RXI0 */
  (void*) OS_ISR_Rx,

  /* 195 SCIF SCIF0 TXI0 */
  (void*) OS_ISR_Tx,
#else
  /* 192 SCIF SCIF0 BRI0 */
  (void*) INT_SCIF_SCIF0_BRI0,

  /* 193 SCIF SCIF0 ERI0 */
  (void*) INT_SCIF_SCIF0_ERI0,

  /* 194 SCIF SCIF0 RXI0 */
  (void*) INT_SCIF_SCIF0_RXI0,

  /* 195 SCIF SCIF0 TXI0 */
  (void*) INT_SCIF_SCIF0_TXI0,
#endif  

#if (OS_UART_USED && (OS_UART == 1))
  /* 196 SCIF SCIF1 BRI1 */
  (void*)  OS_ISR_RxErr,

  /* 197 SCIF SCIF1 ERI1 */
  (void*) OS_ISR_RxErr,

  /* 198 SCIF SCIF1 RXI1 */
  (void*) OS_ISR_Rx,

  /* 199 SCIF SCIF1 TXI1 */
  (void*) OS_ISR_Tx,
#else
  /* 196 SCIF SCIF1 BRI1 */
  (void*) INT_SCIF_SCIF1_BRI1,

  /* 197 SCIF SCIF1 ERI1 */
  (void*) INT_SCIF_SCIF1_ERI1,

  /* 198 SCIF SCIF1 RXI1 */
  (void*) INT_SCIF_SCIF1_RXI1,

  /* 199 SCIF SCIF1 TXI1 */
  (void*) INT_SCIF_SCIF1_TXI1,
#endif

/* 200 SCIF SCIF2 BRI2 */
(void*) INT_SCIF_SCIF2_BRI2,

#if (OS_UART_USED && (OS_UART == 2))
  /* 201 SCIF SCIF2 ERI2 */
  (void*) OS_ISR_RxErr,

  /* 202 SCIF SCIF2 RXI2 */
  (void*) OS_ISR_Rx,

  /* 203 SCIF SCIF2 TXI2 */
  (void*) OS_ISR_Tx,
#else
  /* 201 SCIF SCIF2 ERI2 */
  (void*) INT_SCIF_SCIF2_ERI2,

  /* 202 SCIF SCIF2 RXI2 */
  (void*) INT_SCIF_SCIF2_RXI2,

  /* 203 SCIF SCIF2 TXI2 */
  (void*) INT_SCIF_SCIF2_TXI2,
#endif

/* 204 SCIF SCIF3 BRI3 */
(void*) INT_SCIF_SCIF3_BRI3,

#if (OS_UART_USED && (OS_UART == 2))
  /* 205 SCIF SCIF3 ERI3 */
  (void*) OS_ISR_RxErr,

  /* 206 SCIF SCIF3 RXI3 */
  (void*) OS_ISR_Rx,

  /* 207 SCIF SCIF3 TXI3 */
  (void*) OS_ISR_Tx,
#else
  /* 205 SCIF SCIF3 ERI3 */
  (void*) INT_SCIF_SCIF3_ERI3,

  /* 206 SCIF SCIF3 RXI3 */
  (void*) INT_SCIF_SCIF3_RXI3,

  /* 207 SCIF SCIF3 TXI3 */
  (void*) INT_SCIF_SCIF3_TXI3,
#endif

/* 208 SSU0 SSERI0 */
(void*) INT_SSU0_SSERI0,

/* 209 SSU0 SSRXI0  */
(void*) INT_SSU0_SSRXI0,

/* 210 SSU0 SSTXI0  */
(void*) INT_SSU0_SSTXI0,

/* 211 SSU1 SSERI1 */
(void*) INT_SSU1_SSERI1,

/* 212 SSU1 SSRXI1  */
(void*) INT_SSU1_SSRXI1,

/* 213 SSU1 SSTXI1  */
(void*) INT_SSU1_SSTXI1,

/* 214 SSI SSI0 */
(void*) INT_SSI_SSII0,

/* 215 SSI SSI1  */
(void*) INT_SSI_SSII1,

/* 216 SSI SSI2  */
(void*) INT_SSI_SSII2,

/* 217 SSI SSI3 */
(void*) INT_SSI_SSII3,

/* 218 Reserved */
(void*) Dummy,

/* 219 Reserved */
(void*) Dummy,

/* 220 Reserved */
(void*) Dummy,

/* 221 Reserved */
(void*) Dummy,

/* 222 Reserved */
(void*) Dummy,

/* 223 Reserved */
(void*) Dummy,

/* 224 FLCTL FLSTEI  */
(void*) INT_FLCTL_FLSTEI,

/* 225 FLCTL FLTENDI  */
(void*) INT_FLCTL_FLTENDI,

/* 226 FLCTL FLTREQ0I */
(void*) INT_FLCTL_FLTREQ0I,

/* 227 FLCTL FLTREQ1I  */
(void*) INT_FLCTL_FLTREQ1I,

/* 228 Reserved */
(void*) Dummy,

/* 229 Reserved */
(void*) Dummy,

/* 230 Reserved */
(void*) Dummy,

/* 231 RTC ARM */
(void*) INT_RTC_ARM,

/* 232 RTC PRD */
(void*) INT_RTC_PRD,

/* 233 RTC CUP */
(void*) INT_RTC_CUP,

/* 234 RCANTL1 RCAN0_ERS0 */
(void*) INT_RCANTL1_RCAN0_ERS0,

/* 235 RCANTL1 RCAN0_OVR0 */
(void*) INT_RCANTL1_RCAN0_OVR0,

/* 236 RCANTL1 RCAN0_RM00 */
(void*) INT_RCANTL1_RCAN0_RM00,

/* 237 RCANTL1 RCAN0_RM10 */
(void*) INT_RCANTL1_RCAN0_RM10,

/* 238 RCANTL1 RCAN0_SLE0 */
(void*) INT_RCANTL1_RCAN0_SLE0,

/* 239 RCANTL1 RCAN0_ERS1 */
(void*) INT_RCANTL1_RCAN0_ERS1,

/* 240 RCANTL1 RCAN0_OVR1 */
(void*) INT_RCANTL1_RCAN0_OVR1,

/* 241 RCANTL1 RCAN1_RM01 */
(void*) INT_RCANTL1_RCAN1_RM01,

/* 242 RCANTL1 RCAN1_RM11 */
(void*) INT_RCANTL1_RCAN1_RM11,

/* 243 RCANTL1 RCAN1_SLE1 */
(void*) INT_RCANTL1_RCAN1_SLE1,

#pragma section

};
/**********************************************************************************
End of File
***********************************************************************************/
